telepathy-qt: dbus-tubes: Rename FeatureDBusTube into FeatureCore

Dario Freddi drf at kemper.freedesktop.org
Tue Jul 3 15:08:42 PDT 2012


Module: telepathy-qt
Branch: master
Commit: dc3af232e83effe29435176046f70089d0946751
URL:    http://cgit.freedesktop.org/telepathy/telepathy-qt/commit/?id=dc3af232e83effe29435176046f70089d0946751

Author: Dario Freddi <dario.freddi at collabora.com>
Date:   Thu Nov  3 22:01:58 2011 +0100

dbus-tubes: Rename FeatureDBusTube into FeatureCore

---

 TelepathyQt/dbus-tube-channel.cpp          |   24 ++++++++++++------------
 TelepathyQt/dbus-tube-channel.h            |    2 +-
 TelepathyQt/incoming-dbus-tube-channel.cpp |    8 ++++----
 TelepathyQt/outgoing-dbus-tube-channel.cpp |    6 +++---
 4 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/TelepathyQt/dbus-tube-channel.h b/TelepathyQt/dbus-tube-channel.h
index 5f817f8..b269aee 100644
--- a/TelepathyQt/dbus-tube-channel.h
+++ b/TelepathyQt/dbus-tube-channel.h
@@ -38,7 +38,7 @@ class TP_QT_EXPORT DBusTubeChannel : public TubeChannel
     Q_DISABLE_COPY(DBusTubeChannel)
 
 public:
-    static const Feature FeatureDBusTube;
+    static const Feature FeatureCore;
     static const Feature FeatureBusNameMonitoring;
 
     static DBusTubeChannelPtr create(const ConnectionPtr &connection,
diff --git a/TelepathyQt/outgoing-dbus-tube-channel.cpp b/TelepathyQt/outgoing-dbus-tube-channel.cpp
index 1786243..940f1b0 100644
--- a/TelepathyQt/outgoing-dbus-tube-channel.cpp
+++ b/TelepathyQt/outgoing-dbus-tube-channel.cpp
@@ -84,7 +84,7 @@ OutgoingDBusTubeChannel::Private::~Private()
  *
  * Before being ready to offer the tube, we must be sure the required features on our object
  * are ready. In this case, we need to enable TubeChannel::FeatureTube
- * and DBusTubeChannel::FeatureDBusTube.
+ * and DBusTubeChannel::FeatureCore.
  *
  * DBusTubeChannel features can be enabled by constructing a ChannelFactory and enabling the desired features,
  * and passing it to ChannelRequest or ClientRegistrar when creating them as appropriate. However,
@@ -170,8 +170,8 @@ PendingDBusTubeConnection *OutgoingDBusTubeChannel::offerTube(const QVariantMap
                                         SocketAccessControlCredentials :
                                         SocketAccessControlLocalhost;
 
-    if (!isReady(DBusTubeChannel::FeatureDBusTube)) {
-        warning() << "DBusTubeChannel::FeatureDBusTube must be ready before "
+    if (!isReady(DBusTubeChannel::FeatureCore)) {
+        warning() << "DBusTubeChannel::FeatureCore must be ready before "
             "calling offerTube";
         return new PendingDBusTubeConnection(QLatin1String(TP_QT_ERROR_NOT_AVAILABLE),
                 QLatin1String("Channel not ready"), OutgoingDBusTubeChannelPtr(this));



More information about the telepathy-commits mailing list
diff --git a/TelepathyQt/dbus-tube-channel.cpp b/TelepathyQt/dbus-tube-channel.cpp
index d35bd12..ec6072a 100644
--- a/TelepathyQt/dbus-tube-channel.cpp
+++ b/TelepathyQt/dbus-tube-channel.cpp
@@ -76,11 +76,11 @@ DBusTubeChannel::Private::Private(DBusTubeChannel *parent)
         QStringList(),                                                          // dependsOnInterfaces
         (ReadinessHelper::IntrospectFunc) &Private::introspectDBusTube,
         this);
-    introspectables[DBusTubeChannel::FeatureDBusTube] = introspectableDBusTube;
+    introspectables[DBusTubeChannel::FeatureCore] = introspectableDBusTube;
 
     ReadinessHelper::Introspectable introspectableBusNamesMonitoring(
         QSet<uint>() << 0,                                                      // makesSenseForStatuses
-        Features() << DBusTubeChannel::FeatureDBusTube,                         // dependsOnFeatures (core)
+        Features() << DBusTubeChannel::FeatureCore,                         // dependsOnFeatures (core)
         QStringList(),                                                          // dependsOnInterfaces
         (ReadinessHelper::IntrospectFunc) &Private::introspectBusNamesMonitoring,
         this);
@@ -143,7 +143,7 @@ void DBusTubeChannel::Private::introspectDBusTube(DBusTubeChannel::Private *self
     if (parent->immutableProperties().contains(TP_QT_IFACE_CHANNEL_TYPE_DBUS_TUBE + QLatin1String(".ServiceName")) &&
         parent->immutableProperties().contains(TP_QT_IFACE_CHANNEL_TYPE_DBUS_TUBE + QLatin1String(".SupportedAccessControls"))) {
         self->extractProperties(parent->immutableProperties());
-        self->readinessHelper->setIntrospectCompleted(DBusTubeChannel::FeatureDBusTube, true);
+        self->readinessHelper->setIntrospectCompleted(DBusTubeChannel::FeatureCore, true);
     } else {
         Client::ChannelTypeDBusTubeInterface *dbusTubeInterface =
                 parent->interface<Client::ChannelTypeDBusTubeInterface>();
@@ -184,7 +184,7 @@ void DBusTubeChannel::Private::introspectDBusTube(DBusTubeChannel::Private *self
  * DBusTubeChannel methods.
  * See specific methods documentation for more details.
  */
-const Feature DBusTubeChannel::FeatureDBusTube = Feature(QLatin1String(DBusTubeChannel::staticMetaObject.className()), 0);
+const Feature DBusTubeChannel::FeatureCore = Feature(QLatin1String(DBusTubeChannel::staticMetaObject.className()), 0);
 /**
  * Feature used in order to monitor connections to this tube.
  * Please note that this feature makes sense only in Group tubes.
@@ -241,15 +241,15 @@ DBusTubeChannel::~DBusTubeChannel()
 /**
  * Returns the service name which will be used over the tube.
  *
  * This method requires DBusTubeChannel::FeatureDBusTube to be enabled.
  *
  * \return the service name that will be used over the tube
  */
 QString DBusTubeChannel::serviceName() const
 {
-    if (!isReady(FeatureDBusTube)) {
+    if (!isReady(FeatureCore)) {
         warning() << "DBusTubeChannel::service() used with "
-            "FeatureDBusTube not ready";
+            "FeatureCore not ready";
         return QString();
     }
 
@@ -269,7 +269,7 @@ QString DBusTubeChannel::serviceName() const
  * The listening process will disconnect the connection unless it can determine
  * by OS-specific means that the connecting process has the same user ID as the listening process.
  *
  * This method requires DBusTubeChannel::FeatureDBusTube to be enabled.
  *
  * \note It is strongly advised to call this method before attempting to call
  *       #IncomingDBusTubeChannel::acceptTube or
@@ -285,9 +285,9 @@ QString DBusTubeChannel::serviceName() const
  */
 bool DBusTubeChannel::supportsCredentials() const
 {
-    if (!isReady(FeatureDBusTube)) {
+    if (!isReady(FeatureCore)) {
         warning() << "DBusTubeChannel::supportsCredentials() used with "
-            "FeatureDBusTube not ready";
+            "FeatureCore not ready";
         return false;
     }
 
@@ -351,11 +351,11 @@ void DBusTubeChannel::onRequestAllPropertiesFinished(PendingOperation *op)
         }
 
         mPriv->extractProperties(qualifiedMap);
-        mPriv->readinessHelper->setIntrospectCompleted(DBusTubeChannel::FeatureDBusTube, true);
+        mPriv->readinessHelper->setIntrospectCompleted(DBusTubeChannel::FeatureCore, true);
     } else {
         warning().nospace() << "RequestAllProperties failed "
             "with " << op->errorName() << ": " << op->errorMessage();
-        mPriv->readinessHelper->setIntrospectCompleted(DBusTubeChannel::FeatureDBusTube, false);
+        mPriv->readinessHelper->setIntrospectCompleted(DBusTubeChannel::FeatureCore, false);
     }
 }
 
@@ -241,15 +241,15 @@ DBusTubeChannel::~DBusTubeChannel()
  * Returns the service name which will be used over the tube.
  *
- * This method requires DBusTubeChannel::FeatureDBusTube to be enabled.
+ * This method requires DBusTubeChannel::FeatureCore to be enabled.
  *
  * \return the service name that will be used over the tube
@@ -269,7 +269,7 @@ QString DBusTubeChannel::serviceName() const
  * by OS-specific means that the connecting process has the same user ID as the listening process.
  *
- * This method requires DBusTubeChannel::FeatureDBusTube to be enabled.
+ * This method requires DBusTubeChannel::FeatureCore to be enabled.
  *
  * \note It is strongly advised to call this method before attempting to call
diff --git a/TelepathyQt/incoming-dbus-tube-channel.cpp b/TelepathyQt/incoming-dbus-tube-channel.cpp
index 7a8d1be..5e79be6 100644
--- a/TelepathyQt/incoming-dbus-tube-channel.cpp
+++ b/TelepathyQt/incoming-dbus-tube-channel.cpp
@@ -108,7 +108,7 @@ IncomingDBusTubeChannel::Private::~Private()
  *
  * Before being ready to accept the tube, we must be sure the required features on our object
  * are ready. In this case, we need to enable TubeChannel::FeatureTube and
- * DBusTubeChannel::FeatureDBusTube.
+ * DBusTubeChannel::FeatureCore.
  *
  * DBusTubeChannel features can be enabled by constructing a ChannelFactory and enabling the desired features,
  * and passing it to ChannelRequest or ClientRegistrar when creating them as appropriate. However,
@@ -189,7 +189,7 @@ IncomingDBusTubeChannel::~IncomingDBusTubeChannel()
  * which can be used to communicate with the other end. You can then
  * retrieve the address either from \c PendingDBusTubeConnection or from %address().
  *
  * This method requires DBusTubeChannel::FeatureDBusTube to be enabled.
  *
  * \param requireCredentials Whether the server should require an SCM_CREDENTIALS message
  *                           upon connection.
@@ -203,8 +203,8 @@ PendingDBusTubeConnection *IncomingDBusTubeChannel::acceptTube(bool requireCrede
                                         SocketAccessControlCredentials :
                                         SocketAccessControlLocalhost;
 
-    if (!isReady(DBusTubeChannel::FeatureDBusTube)) {
-        warning() << "DBusTubeChannel::FeatureDBusTube must be ready before "
+    if (!isReady(DBusTubeChannel::FeatureCore)) {
+        warning() << "DBusTubeChannel::FeatureCore must be ready before "
             "calling offerTube";
         return new PendingDBusTubeConnection(QLatin1String(TP_QT_ERROR_NOT_AVAILABLE),
                 QLatin1String("Channel not ready"), IncomingDBusTubeChannelPtr(this));
@@ -189,7 +189,7 @@ IncomingDBusTubeChannel::~IncomingDBusTubeChannel()
  * retrieve the address either from \c PendingDBusTubeConnection or from %address().
  *
- * This method requires DBusTubeChannel::FeatureDBusTube to be enabled.
+ * This method requires DBusTubeChannel::FeatureCore to be enabled.
  *
  * \param requireCredentials Whether the server should require an SCM_CREDENTIALS message